@@ -1,21 +1,29 @@
 ##----------------------------------------------------------------------------
-## Stripe API - ~/lib/Net/API/Stripe/Dispute.pm
-## Version v0.100.0
-## Copyright(c) 2019 DEGUEST Pte. Ltd.
-## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
+## Stripe API - ~/usr/local/src/perl/Net-API-Stripe/lib/Net/API/Stripe/Dispute.pm
+## Version v0.101.0
+## Copyright(c) 2020 DEGUEST Pte. Ltd.
+## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2019/11/02
-## Modified 2020/05/15
+## Modified 2020/11/16
+## All rights reserved
 ## 
+## This program is free software; you can redistribute  it  and/or  modify  it
+## under the same terms as Perl itself.
 ##----------------------------------------------------------------------------
 ## https://stripe.com/docs/api/disputes/object
 package Net::API::Stripe::Dispute;
 BEGIN
 {
     use strict;
+    use warnings;
     use parent qw( Net::API::Stripe::Generic );
-    our( $VERSION ) = 'v0.100.0';
+    use vars qw( $VERSION );
+    our( $VERSION ) = 'v0.101.0';
 };
 
+use strict;
+use warnings;
+
 sub id { return( shift->_set_get_scalar( 'id', @_ ) ); }
 
 sub object { return( shift->_set_get_scalar( 'object', @_ ) ); }
@@ -45,6 +53,8 @@ sub livemode { return( shift->_set_get_boolean( 'livemode', @_ ) ); }
 
 sub metadata { return( shift->_set_get_hash( 'metadata', @_ ) ); }
 
+sub payment_intent { return( shift->_set_get_scalar_or_object( 'payment_intent', 'Net::API::Stripe::Payment::Intent', @_ ) ); }
+
 sub reason { return( shift->_set_get_scalar( 'reason', @_ ) ); }
 
 sub status { return( shift->_set_get_scalar( 'status', @_ ) ); }
@@ -79,7 +89,7 @@ See documentation in L<Net::API::Stripe> for example to make api calls to Stripe
 
 =head1 VERSION
 
-    v0.100.0
+    v0.101.0
 
 =head1 DESCRIPTION
 
@@ -89,197 +99,197 @@ A dispute occurs when a customer questions your charge with their card issuer. W
 
 =head1 CONSTRUCTOR
 
-=over 4
-
-=item B<new>( %ARG )
+=head2 new( %ARG )
 
 Creates a new L<Net::API::Stripe::Dispute> object.
 
-=back
-
 =head1 METHODS
 
-=over 4
-
-=item B<id> string
+=head2 id string
 
 Unique identifier for the object.
 
-=item B<object> string, value is "dispute"
+=head2 object string, value is "dispute"
 
 String representing the object’s type. Objects of the same type share the same value.
 
-=item B<amount> integer
+=head2 amount integer
 
 Disputed amount. Usually the amount of the charge, but can differ (usually because of currency fluctuation or because only part of the order is disputed).
 
-=item B<balance_transaction>
+=head2 balance_transaction
 
 It seems this property is removed from the API documentation or maybe an omission?
 
 This is an id or a L<Net::API::Stripe::Balance::Transaction> object.
 
-=item B<balance_transactions> array, contains: balance_transaction object
+=head2 balance_transactions array, contains: balance_transaction object
 
 List of zero, one, or two balance transactions that show funds withdrawn and reinstated to your Stripe account as a result of this dispute.
 
 This is an array of L<Net::API::Stripe::Balance::Transaction> objects.
 
-=item B<charge> string (expandable)
+=head2 charge string (expandable)
 
 ID of the charge that was disputed or an L<Net::API::Stripe::Charge> object.
 
-=item B<created> timestamp
+=head2 created timestamp
 
 Time at which the object was created. Measured in seconds since the Unix epoch.
 
-=item B<currency> currency
+=head2 currency currency
 
 Three-letter ISO currency code, in lowercase. Must be a supported currency.
 
-=item B<disputed_transaction> string (expandable)
+=head2 disputed_transaction string (expandable)
 
 When expanded, this is a L<Net::API::Stripe::Balance::Transaction> object.
 
-=item B<evidence> hash
+=head2 evidence hash
 
 Evidence provided to respond to a dispute. Updating any field in the hash will submit all fields in the hash for review.
 
-=over 8
+Below is the list of types and also L<available on the web|https://stripe.com/docs/disputes/categories>.
 
-=item B<access_activity_log>
+=over 4
 
-=item B<billing_address>
+=item * access_activity_log
 
-=item B<cancellation_policy>
+=item * billing_address
 
-=item B<cancellation_policy_disclosure>
+=item * cancellation_policy
 
-=item B<cancellation_rebuttal>
+=item * cancellation_policy_disclosure
 
-=item B<customer_communication>
+=item * cancellation_rebuttal
 
-=item B<customer_email_address>
+=item * customer_communication
 
-=item B<customer_name>
+=item * customer_email_address
 
-=item B<customer_purchase_ip>
+=item * customer_name
 
-=item B<customer_signature>
+=item * customer_purchase_ip
 
-=item B<duplicate_charge_documentation>
+=item * customer_signature
 
-=item B<duplicate_charge_explanation>
+=item * duplicate_charge_documentation
 
-=item B<duplicate_charge_id>
+=item * duplicate_charge_explanation
 
-=item B<product_description>
+=item * duplicate_charge_id
 
-=item B<receipt>
+=item * product_description
 
-=item B<refund_policy>
+=item * receipt
 
-=item B<refund_policy_disclosure>
+=item * refund_policy
 
-=item B<refund_refusal_explanation>
+=item * refund_policy_disclosure
 
-=item B<service_date>
+=item * refund_refusal_explanation
 
-=item B<service_documentation>
+=item * service_date
 
-=item B<shipping_address>
+=item * service_documentation
 
-=item B<shipping_carrier>
+=item * shipping_address
 
-=item B<shipping_date>
+=item * shipping_carrier
 
-=item B<shipping_documentation>
+=item * shipping_date
 
-=item B<shipping_tracking_number>
+=item * shipping_documentation
 
-=item B<uncategorized_file>
+=item * shipping_tracking_number
 
-=item B<uncategorized_text>
+=item * uncategorized_file
+
+=item * uncategorized_text
 
 =back
 
-=item B<evidence_details> hash
+=head2 evidence_details hash
 
 Information about the evidence submission. This is a L<Net::API::Stripe::Dispute::EvidenceDetails> object.
 
-=item B<is_charge_refundable> boolean
+=head2 is_charge_refundable boolean
 
 If true, it is still possible to refund the disputed payment. Once the payment has been fully refunded, no further funds will be withdrawn from your Stripe account as a result of this dispute.
 
-=item B<livemode> boolean
+=head2 livemode boolean
 
 Has the value true if the object exists in live mode or the value false if the object exists in test mode.
 
-=item B<metadata> hash
+=head2 metadata hash
 
 Set of key-value pairs that you can attach to an object. This can be useful for storing additional information about the object in a structured format.
 
-=item B<reason> string
+=head2 payment_intent expandable
+
+ID of the PaymentIntent that was disputed.
+
+When expanded this is an L<Net::API::Stripe::Payment::Intent> object.
+
+=head2 reason string
 
 Reason given by cardholder for dispute. Possible values are bank_cannot_process, check_returned, credit_not_processed, customer_initiated, debit_not_authorized, duplicate, fraudulent, general, incorrect_account_details, insufficient_funds, product_not_received, product_unacceptable, subscription_canceled, or unrecognized. Read more about dispute reasons.
 
-=item B<status> string
+=head2 status string
 
 Current status of dispute. Possible values are warning_needs_response, warning_under_review, warning_closed, needs_response, under_review, charge_refunded, won, or lost.
 
-=back
-
 =head1 API SAMPLE
 
-	{
-	  "id": "dp_fake123456789",
-	  "object": "dispute",
-	  "amount": 1000,
-	  "balance_transactions": [],
-	  "charge": "ch_fake123456789",
-	  "created": 1571197169,
-	  "currency": "jpy",
-	  "evidence": {
-		"access_activity_log": null,
-		"billing_address": null,
-		"cancellation_policy": null,
-		"cancellation_policy_disclosure": null,
-		"cancellation_rebuttal": null,
-		"customer_communication": null,
-		"customer_email_address": null,
-		"customer_name": null,
-		"customer_purchase_ip": null,
-		"customer_signature": null,
-		"duplicate_charge_documentation": null,
-		"duplicate_charge_explanation": null,
-		"duplicate_charge_id": null,
-		"product_description": null,
-		"receipt": null,
-		"refund_policy": null,
-		"refund_policy_disclosure": null,
-		"refund_refusal_explanation": null,
-		"service_date": null,
-		"service_documentation": null,
-		"shipping_address": null,
-		"shipping_carrier": null,
-		"shipping_date": null,
-		"shipping_documentation": null,
-		"shipping_tracking_number": null,
-		"uncategorized_file": null,
-		"uncategorized_text": null
-	  },
-	  "evidence_details": {
-		"due_by": 1572911999,
-		"has_evidence": false,
-		"past_due": false,
-		"submission_count": 0
-	  },
-	  "is_charge_refundable": true,
-	  "livemode": false,
-	  "metadata": {},
-	  "reason": "general",
-	  "status": "warning_needs_response"
-	}
+    {
+      "id": "dp_fake123456789",
+      "object": "dispute",
+      "amount": 1000,
+      "balance_transactions": [],
+      "charge": "ch_fake123456789",
+      "created": 1571197169,
+      "currency": "jpy",
+      "evidence": {
+        "access_activity_log": null,
+        "billing_address": null,
+        "cancellation_policy": null,
+        "cancellation_policy_disclosure": null,
+        "cancellation_rebuttal": null,
+        "customer_communication": null,
+        "customer_email_address": null,
+        "customer_name": null,
+        "customer_purchase_ip": null,
+        "customer_signature": null,
+        "duplicate_charge_documentation": null,
+        "duplicate_charge_explanation": null,
+        "duplicate_charge_id": null,
+        "product_description": null,
+        "receipt": null,
+        "refund_policy": null,
+        "refund_policy_disclosure": null,
+        "refund_refusal_explanation": null,
+        "service_date": null,
+        "service_documentation": null,
+        "shipping_address": null,
+        "shipping_carrier": null,
+        "shipping_date": null,
+        "shipping_documentation": null,
+        "shipping_tracking_number": null,
+        "uncategorized_file": null,
+        "uncategorized_text": null
+      },
+      "evidence_details": {
+        "due_by": 1572911999,
+        "has_evidence": false,
+        "past_due": false,
+        "submission_count": 0
+      },
+      "is_charge_refundable": true,
+      "livemode": false,
+      "metadata": {},
+      "reason": "general",
+      "status": "warning_needs_response"
+    }
 
 =head1 HISTORY
 
@@ -305,4 +315,3 @@ You can use, copy, modify and redistribute this package and associated
 files under the same terms as Perl itself.
 
 =cut
-
